//
//  NewsTableViewController.swift
//  SidebarMenu
//
//  Created by Simon Ng on 2/2/15.
//  Copyright (c) 2015 AppCoda. All rights reserved.
//

import UIKit

class NewsTableViewController: UITableViewController, UISearchBarDelegate, UISearchDisplayDelegate {
    @IBOutlet var menuButton:UIBarButtonItem!
    @IBOutlet var extraButton:UIBarButtonItem!
    var filteredEntries_Text = [String]()
    var filteredEntries_Date = [String]()
    var filteredEntries_Index = [Int]()
        
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.tableView.sectionFooterHeight = 10
        self.tableView.sectionHeaderHeight = 0
        
        self.automaticallyAdjustsScrollViewInsets = false;
        
        navigationController?.navigationBar.translucent = false;
        navigationController?.navigationBar.barTintColor = UIColor.init(red: 139/255.0, green: 2/255.0, blue: 45/255.0, alpha: 1)
        navigationController?.navigationBar.tintColor = UIColor.whiteColor()
        navigationController?.navigationBar.titleTextAttributes = [
            NSForegroundColorAttributeName:UIColor.whiteColor(),
            NSFontAttributeName: UIFont(name: "ProximaNova-Regular", size: 17)!
        ]

        if revealViewController() != nil {
//            revealViewController().rearViewRevealWidth = 62
            menuButton.target = revealViewController()
            menuButton.action = "revealToggle:"

//            revealViewController().rightViewRevealWidth = 150
//            extraButton.target = revealViewController()
//            extraButton.action = "rightRevealToggle:"

            view.addGestureRecognizer(self.revealViewController().panGestureRecognizer())
            
        
        }
        
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: - Table view data source

    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        // Return the number of sections.
        
        if tableView == self.searchDisplayController!.searchResultsTableView {
            return 1
        } else {
            return pastEntryContent.count
        }
        
    }

    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if tableView == self.searchDisplayController!.searchResultsTableView {
            return self.filteredEntries_Text.count
        } else {
            return 1
        }
    }

    
    override func tableView(tableView: UITableView, heightForRowAtIndexPath indexPath: NSIndexPath) -> CGFloat {
        
        if tableView == self.searchDisplayController!.searchResultsTableView {
            
            return 110
            
        } else {
            if pastEntryContent[indexPath.section]["image"] == nil {
                return 115
            } else {
                return 240
            }
        }
    }
    
    
    override func tableView(tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        if section == 0 {
            return 0
        } else {
            return 0
        }
    }
        
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        
        // Check to see whether the normal table or search results table is being displayed and set the Candy object from the appropriate array
        if tableView == self.searchDisplayController!.searchResultsTableView {
            let cell = self.tableView.dequeueReusableCellWithIdentifier("Cell") as! NewsTableViewCell
            cell.preview.text = self.filteredEntries_Text[indexPath.row]
            cell.postTitleLabel.text = self.filteredEntries_Date[indexPath.row]
            return cell
        } else {
            
            let cell = tableView.dequeueReusableCellWithIdentifier("Cell", forIndexPath: indexPath) as! NewsTableViewCell
            if pastEntryContent[indexPath.section]["image"] != nil {
                cell.postImageView.image = UIImage(named: pastEntryContent[indexPath.section]["image"]!)
            }
            cell.postTitleLabel.text = pastEntryContent[indexPath.section]["date"]
            var preview = pastEntryContent[indexPath.section]["text"]
            preview = preview?.substringFromIndex(advance(preview!.startIndex, 5))
            cell.preview.text = preview

            return cell
        }
    }

    override func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
        //performSegueWithIdentifier("unfilteredSegue", sender: self)
    }
        
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        if self.filteredEntries_Date.count > 0 {
            
            let indexPath = self.searchDisplayController!.searchResultsTableView.indexPathForSelectedRow()!
            
            let nav = segue.destinationViewController as! UINavigationController
            let destController = nav.topViewController as! PastEntryFullViewController
            let dateLabelText = self.filteredEntries_Date[indexPath.row]
            let bodyText = self.filteredEntries_Text[indexPath.row]
            destController.pastEntryIndex = self.filteredEntries_Index[indexPath.row]
        
        } else {
            
            let path = self.tableView.indexPathForSelectedRow()!
            let content = pastEntryContent[path.section]
            let nav = segue.destinationViewController as! UINavigationController
            let destController = nav.topViewController as! PastEntryFullViewController
            destController.pastEntryIndex = path.section
            
        }
        
        
    }
    
    
    func filterContentForSearchText(searchText: String) {
        
        for i in 0...pastEntryContent.count-1 {
            let entry = pastEntryContent[i]
            if entry["text"]!.lowercaseString.rangeOfString(searchText.lowercaseString) != nil || entry["date"]!.lowercaseString.rangeOfString(searchText.lowercaseString) != nil {
                self.filteredEntries_Date.append(entry["date"]!)
                var preview = entry["text"]
                preview = preview?.substringFromIndex(advance(preview!.startIndex, 5))
                self.filteredEntries_Text.append(preview!)
                self.filteredEntries_Index.append(i)
            }
        }
    }

    
    func searchDisplayController(controller: UISearchDisplayController!, shouldReloadTableForSearchString searchString: String!) -> Bool {
        
        self.filteredEntries_Date.removeAll()
        self.filteredEntries_Text.removeAll()
        self.filteredEntries_Index.removeAll()
        
        self.filterContentForSearchText(searchString)
        
        return true
        
    }
    
    func searchBarCancelButtonClicked(searchBar: UISearchBar) {
        self.filteredEntries_Date.removeAll()
        self.filteredEntries_Text.removeAll()
    }
    
    /*
    // Override to support conditional editing of the table view.
    override func tableView(tableView: UITableView, canEditRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        // Return NO if you do not want the specified item to be editable.
        return true
    }
    */

    /*
    // Override to support editing the table view.
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            // Delete the row from the data source
            tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)
        } else if editingStyle == .Insert {
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
        }    
    }
    */

    /*
    // Override to support rearranging the table view.
    override func tableView(tableView: UITableView, moveRowAtIndexPath fromIndexPath: NSIndexPath, toIndexPath: NSIndexPath) {

    }
    */

    /*
    // Override to support conditional rearranging of the table view.
    override func tableView(tableView: UITableView, canMoveRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        // Return NO if you do not want the item to be re-orderable.
        return true
    }
    */

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using [segue destinationViewController].
        // Pass the selected object to the new view controller.
    }
    */

}
