//
//  PhotoViewController.swift
//  SidebarMenu
//
//  Created by Simon Ng on 2/2/15.
//  Copyright (c) 2015 AppCoda. All rights reserved.
//

import UIKit

protocol todayController {
    func selectedPin(index: Int)
}

class PhotoViewController: UIViewController, UIPopoverPresentationControllerDelegate, UITextViewDelegate, todayController {
    @IBOutlet weak var menuButton:UIBarButtonItem!
    @IBOutlet weak var journalTextView: UITextView!
    @IBOutlet weak var dateLabel: UILabel!
    @IBOutlet weak var imageView: UIImageView!
    @IBOutlet weak var doneButton: UIBarButtonItem!

    var imageNames = ["tweet", "fbphotos", "text"]
    
    override func viewDidLoad() {
        super.viewDidLoad()

        navigationController?.navigationBar.barTintColor = UIColor.init(red: 139/255.0, green: 2/255.0, blue: 45/255.0, alpha: 1)
        navigationController?.navigationBar.tintColor = UIColor.whiteColor()
        navigationController?.navigationBar.titleTextAttributes = [
            NSForegroundColorAttributeName:UIColor.whiteColor(),
            NSFontAttributeName: UIFont(name: "ProximaNova-Regular", size: 17)!
        ]
        if revealViewController() != nil {
            menuButton.target = revealViewController()
            menuButton.action = "revealToggle:"
            view.addGestureRecognizer(self.revealViewController().panGestureRecognizer())
        }
        
        let date = NSDate()
        let dateFormatter = NSDateFormatter()
        dateFormatter.dateStyle = .LongStyle
        
        let dateString = dateFormatter.stringFromDate(date)
        dateLabel.text = dateString;
        dateLabel.font = UIFont(name: "RobotoSlab-Bold", size: 18)
        
        journalTextView.delegate = self
        if todayText == "" {
            journalTextView.text = "Start writing..."
            journalTextView.textColor = UIColor.lightGrayColor()
        } else {
            journalTextView.text = todayText
            journalTextView.textColor = UIColor.blackColor()
        }
        journalTextView.font = UIFont(name: "RobotoSlab-Light", size: 15)
        
        if let imgName = todayImg {
            imageView.image = UIImage(named: imgName)
        }
        
        doneButton.title = ""
        doneButton.action = "dismissKeyboard:"
    }
    
    func dismissKeyboard(sender: UIBarButtonItem) {
        journalTextView.resignFirstResponder()
        todayText = journalTextView.text
        doneButton.title = ""
        if todayText == "" {
            journalTextView.text = "Start writing..."
            journalTextView.textColor = UIColor.lightGrayColor()
        }
    }
    
    func selectedPin(index: Int) {
        if index == imageNames.count {
            todayImg = nil
            imageView.image = nil
            let str = journalTextView.text
            let strippedstr = str.substringFromIndex(advance(str.startIndex, 6))
            journalTextView.text = strippedstr
        } else {
            if todayImg == nil {
                journalTextView.text = "\n\n\n\n\n\n" + journalTextView.text
            }
            todayImg = imageNames[index]
            imageView.image = UIImage(named: todayImg!)
        }
        
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        if segue.identifier == "popoverSegue" {
            let popoverViewController = segue.destinationViewController as! UIViewController
            popoverViewController.modalPresentationStyle = UIModalPresentationStyle.Popover
            popoverViewController.popoverPresentationController!.delegate = self
            let popoverTableViewController = segue.destinationViewController.viewControllers![0] as! PinTableViewController
            popoverTableViewController.delegate = self
        }
    }
    
    func adaptivePresentationStyleForPresentationController(controller: UIPresentationController) -> UIModalPresentationStyle {
        return UIModalPresentationStyle.None
    }
    
    func textViewDidChange(journalTextView: UITextView) {
        todayText = journalTextView.text
    }
    
    func textViewDidBeginEditing(journalTextView: UITextView) {
        if (journalTextView.textColor == UIColor.lightGrayColor()){
            if (journalTextView.text == "Start writing...") {
                journalTextView.text = ""
            } else {
                journalTextView.text = "\n\n\n\n\n\n"
            }
            journalTextView.textColor = UIColor.blackColor()
        }
        doneButton.title = "Done"
        doneButton.setTitleTextAttributes([NSFontAttributeName: UIFont(name: "ProximaNova-Regular", size: 15)!], forState: UIControlState.Normal)
    }

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
